# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litepie/committee/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/litepie/committee/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Litepie\\Committee\\": "packages/litepie/committee/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litepie\Committee\Providers\CommitteeServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Committee'  => Litepie\Committee\Facades\Committee::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litepie\\CommitteeTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litepie\Committee\Providers\CommitteeServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litepie\Committee\Providers\CommitteeServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litepie\Committee\Providers\CommitteeServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/committee/{modulename}

**User**

    http://path-to-route-folder/user/committee/{modulename}

**Public**

    http://path-to-route-folder/committees


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/committee/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/committee/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/committee/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/committee/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/committee/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/committee/{modulename}/{slug}
    METHOD: GET