<?php

namespace Litepie\Committee\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Committee\Interfaces\CommitteeRepositoryInterface;

class CommitteePublicController extends BaseController
{
    // use CommitteeWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\Committee\Interfaces\CommitteeRepositoryInterface $committee
     *
     * @return type
     */
    public function __construct(CommitteeRepositoryInterface $committee)
    {
        $this->repository = $committee;
        parent::__construct();
    }

    /**
     * Show committee's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $committees = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('committee::committee.names'))
            ->view('committee::public.committee.index')
            ->data(compact('committees'))
            ->output();
    }


    /**
     * Show committee.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $committee = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($committee->name . trans('committee::committee.name'))
            ->view('committee::public.committee.show')
            ->data(compact('committee'))
            ->output();
    }

}
