<?php

namespace Litepie\Committee\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Committee\Models\Committee;

class CommitteePolicy
{

    /**
     * Determine if the given user can view the committee.
     *
     * @param UserPolicy $user
     * @param Committee $committee
     *
     * @return bool
     */
    public function view(UserPolicy $user, Committee $committee)
    {
        if ($user->canDo('committee.committee.view') && $user->isAdmin()) {
            return true;
        }

        return $committee->user_id == user_id() && $committee->user_type == user_type();
    }

    /**
     * Determine if the given user can create a committee.
     *
     * @param UserPolicy $user
     * @param Committee $committee
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('committee.committee.create');
    }

    /**
     * Determine if the given user can update the given committee.
     *
     * @param UserPolicy $user
     * @param Committee $committee
     *
     * @return bool
     */
    public function update(UserPolicy $user, Committee $committee)
    {
        if ($user->canDo('committee.committee.edit') && $user->isAdmin()) {
            return true;
        }

        return $committee->user_id == user_id() && $committee->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given committee.
     *
     * @param UserPolicy $user
     * @param Committee $committee
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Committee $committee)
    {
        return $committee->user_id == user_id() && $committee->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given committee.
     *
     * @param UserPolicy $user
     * @param Committee $committee
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Committee $committee)
    {
        if ($user->canDo('committee.committee.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given committee.
     *
     * @param UserPolicy $user
     * @param Committee $committee
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Committee $committee)
    {
        if ($user->canDo('committee.committee.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
